@@ -1,9 +1,12 @@
-from robot.api.parsing import ModelTransformer, Token
+import string
+
+from robot.api.parsing import Token
 
 from robotidy.disablers import skip_section_if_disabled
+from robotidy.transformers import Transformer
 
 
-class NormalizeSectionHeaderName(ModelTransformer):
+class NormalizeSectionHeaderName(Transformer):
     """
     Normalize section headers names.
     Robot Framework is quite flexible with the section header naming. Following lines are equal:
@@ -30,11 +33,12 @@ class NormalizeSectionHeaderName(ModelTransformer):
     ```robotframework
     *** SETTINGS ***
     ```
-
-    Supports global formatting params: ``--startline`` and ``--endline``.
     """
 
+    EN_SINGULAR_HEADERS = {"comment", "setting", "variable", "task", "test case", "keyword"}
+
     def __init__(self, uppercase: bool = False):
+        super().__init__()
         self.uppercase = uppercase
 
     @skip_section_if_disabled
@@ -42,18 +46,17 @@ class NormalizeSectionHeaderName(ModelTransformer):
         return self.generic_visit(node)
 
     def visit_SectionHeader(self, node):  # noqa
-        if node.name and "task" in node.name.lower():
-            name = "*** Tasks ***"
-        else:
-            name = {
-                Token.SETTING_HEADER: "*** Settings ***",
-                Token.VARIABLE_HEADER: "*** Variables ***",
-                Token.TESTCASE_HEADER: "*** Test Cases ***",
-                Token.KEYWORD_HEADER: "*** Keywords ***",
-                Token.COMMENT_HEADER: "*** Comments ***",
-            }[node.type]
+        if not node.name:
+            return node
+        # only normalize, and if found in english ones then add plural
+        header_name = node.data_tokens[0].value
+        header_name = header_name.replace("*", "").strip()
+        if header_name.lower() in self.EN_SINGULAR_HEADERS:
+            header_name += "s"
         if self.uppercase:
-            name = name.upper()
+            header_name = header_name.upper()
+        else:
+            header_name = string.capwords(header_name)
         # we only modify header token value in order to preserver optional data driven testing column names
-        node.data_tokens[0].value = name
+        node.data_tokens[0].value = f"*** {header_name} ***"
         return node
