@@ -99,8 +99,6 @@ class RenameKeywords(ModelTransformer):
         var_found = False
         parts = []
         new_name, remaining = "", ""
-        if value.strip() == "${keyword}":
-            print()
         for prefix, match, remaining in VariableIterator(value, ignore_errors=True):
             var_found = True
             # rename strips whitespace, so we need to preserve it if needed
