@@ -1,14 +1,14 @@
-import logging
 import re
 from typing import Optional
 
-from robot.api.parsing import ModelTransformer, Token
+from robot.api.parsing import Token
 
 from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
 from robotidy.exceptions import InvalidParameterValueError
+from robotidy.transformers import Transformer
 
 
-class RenameTestCases(ModelTransformer):
+class RenameTestCases(Transformer):
     r"""
     Enforce test case naming.
 
@@ -57,8 +57,6 @@ class RenameTestCases(ModelTransformer):
     Compare XML With Json
         No Operation
     ```
-
-    Supports global formatting params: ``--startline`` and ``--endline``.
     """
     ENABLED = False
 
@@ -68,6 +66,7 @@ class RenameTestCases(ModelTransformer):
         replace_to: Optional[str] = None,
         capitalize_each_word: bool = False,
     ):
+        super().__init__()
         try:
             self.replace_pattern = re.compile(replace_pattern) if replace_pattern is not None else None
         except re.error as err:
